pub struct SequenceBase {
payload: Cow<'static, str>,
terminator: SequenceTerminator,
}Fields
payload: Cow<'static, str>The base of the payload, which is the number and optionally an alt base from the kitty
spec.
terminator: SequenceTerminatorImplementations
Sourceimpl SequenceBase
impl SequenceBase
fn new(payload: Cow<'static, str>, terminator: SequenceTerminator) -> Self