pub struct SequenceBuilder {
mode: TermMode,
kitty_seq: bool,
kitty_encode_all: bool,
kitty_event_type: bool,
modifiers: SequenceModifiers,
}Expand description
Helper to build escape sequence payloads from KeyEvent.
Fields
mode: TermModekitty_seq: boolThe emitted sequence should follow the kitty keyboard protocol.
kitty_encode_all: boolEncode all the keys according to the protocol.
kitty_event_type: boolReport event types.
modifiers: SequenceModifiersImplementations
Sourceimpl SequenceBuilder
impl SequenceBuilder
Sourcefn try_build_textual(
&self,
key: &KeyEvent,
associated_text: Option<&str>,
) -> Option<SequenceBase>
fn try_build_textual( &self, key: &KeyEvent, associated_text: Option<&str>, ) -> Option<SequenceBase>
Try building sequence from the event’s emitting text.
Sourcefn try_build_numpad(&self, key: &KeyEvent) -> Option<SequenceBase>
fn try_build_numpad(&self, key: &KeyEvent) -> Option<SequenceBase>
Try building from numpad key.
None is returned when the key is neither known nor numpad.
Sourcefn try_build_named_kitty(&self, key: &KeyEvent) -> Option<SequenceBase>
fn try_build_named_kitty(&self, key: &KeyEvent) -> Option<SequenceBase>
Try building from NamedKey using the kitty keyboard protocol encoding
for functional keys.
Sourcefn try_build_named_normal(&self, key: &KeyEvent) -> Option<SequenceBase>
fn try_build_named_normal(&self, key: &KeyEvent) -> Option<SequenceBase>
Try building from NamedKey.
Sourcefn try_build_control_char_or_mod(
&self,
key: &KeyEvent,
mods: &mut SequenceModifiers,
) -> Option<SequenceBase>
fn try_build_control_char_or_mod( &self, key: &KeyEvent, mods: &mut SequenceModifiers, ) -> Option<SequenceBase>
Try building escape from control characters (e.g. Enter) and modifiers.